SlickGrid example 14: Highlighting and Flashing cells

## About

This example simulates a real-time display of CPU utilization in a web farm. Data is updated in real-time, and cells with changed data are highlighted. You can also click "Find current server" to scroll the row displaying data for the current server into view and flash it.

## Demonstrates

- setHighlightedCells()
- flashCell()

## Controls

## View Source:

- View the source for this example on Github